@@ -158,17 +158,6 @@ struct dynhds_entry *Curl_dynhds_cget(struct dynhds *dynhds, const char *name)
   return Curl_dynhds_get(dynhds, name, strlen(name));
 }
 
-bool Curl_dynhds_contains(struct dynhds *dynhds,
-                          const char *name, size_t namelen)
-{
-  return !!Curl_dynhds_get(dynhds, name, namelen);
-}
-
-bool Curl_dynhds_ccontains(struct dynhds *dynhds, const char *name)
-{
-  return Curl_dynhds_contains(dynhds, name, strlen(name));
-}
-
 CURLcode Curl_dynhds_add(struct dynhds *dynhds,
                          const char *name, size_t namelen,
                          const char *value, size_t valuelen)
@@ -221,20 +210,6 @@ CURLcode Curl_dynhds_cadd(struct dynhds *dynhds,
   return Curl_dynhds_add(dynhds, name, strlen(name), value, strlen(value));
 }
 
-CURLcode Curl_dynhds_set(struct dynhds *dynhds,
-                         const char *name, size_t namelen,
-                         const char *value, size_t valuelen)
-{
-  Curl_dynhds_remove(dynhds, name, namelen);
-  return Curl_dynhds_add(dynhds, name, namelen, value, valuelen);
-}
-
-CURLcode Curl_dynhds_cset(struct dynhds *dynhds,
-                          const char *name, const char *value)
-{
-  return Curl_dynhds_set(dynhds, name, strlen(name), value, strlen(value));
-}
-
 CURLcode Curl_dynhds_h1_add_line(struct dynhds *dynhds,
                                  const char *line, size_t line_len)
 {
@@ -296,6 +271,20 @@ CURLcode Curl_dynhds_h1_cadd_line(struct dynhds *dynhds, const char *line)
   return Curl_dynhds_h1_add_line(dynhds, line, line? strlen(line) : 0);
 }
 
+#ifdef DEBUGBUILD
+/* used by unit2602.c */
+
+bool Curl_dynhds_contains(struct dynhds *dynhds,
+                          const char *name, size_t namelen)
+{
+  return !!Curl_dynhds_get(dynhds, name, namelen);
+}
+
+bool Curl_dynhds_ccontains(struct dynhds *dynhds, const char *name)
+{
+  return Curl_dynhds_contains(dynhds, name, strlen(name));
+}
+
 size_t Curl_dynhds_count_name(struct dynhds *dynhds,
                               const char *name, size_t namelen)
 {
@@ -305,7 +294,7 @@ size_t Curl_dynhds_count_name(struct dynhds *dynhds,
     for(i = 0; i < dynhds->hds_len; ++i) {
       if((namelen == dynhds->hds[i]->namelen) &&
          strncasecompare(name, dynhds->hds[i]->name, namelen))
-         ++n;
+        ++n;
     }
   }
   return n;
@@ -316,6 +305,14 @@ size_t Curl_dynhds_ccount_name(struct dynhds *dynhds, const char *name)
   return Curl_dynhds_count_name(dynhds, name, strlen(name));
 }
 
+CURLcode Curl_dynhds_set(struct dynhds *dynhds,
+                         const char *name, size_t namelen,
+                         const char *value, size_t valuelen)
+{
+  Curl_dynhds_remove(dynhds, name, namelen);
+  return Curl_dynhds_add(dynhds, name, namelen, value, valuelen);
+}
+
 size_t Curl_dynhds_remove(struct dynhds *dynhds,
                           const char *name, size_t namelen)
 {
@@ -347,6 +344,8 @@ size_t Curl_dynhds_cremove(struct dynhds *dynhds, const char *name)
   return Curl_dynhds_remove(dynhds, name, strlen(name));
 }
 
+#endif
+
 CURLcode Curl_dynhds_h1_dprint(struct dynhds *dynhds, struct dynbuf *dbuf)
 {
   CURLcode result = CURLE_OK;
@@ -365,3 +364,4 @@ CURLcode Curl_dynhds_h1_dprint(struct dynhds *dynhds, struct dynbuf *dbuf)
 
   return result;
 }
+
